@@ -42,8 +42,6 @@ class AbstractDailyWeatherForecast;
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
     QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
@@ -61,7 +59,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #endif
     QQmlApplicationEngine engine;
 
-    KLocalizedString::setApplicationDomain("kweather");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kweather"));
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     KAboutData aboutData(QStringLiteral("kweather"),
                          i18n("Weather"),
