@@ -36,13 +36,13 @@ void TemperatureChartData::updateData()
 
     m_series->clear();
 
-    QVector<QPointF> result;
+    QList<QPointF> result;
     result.reserve(m_weatherData.size());
 
     double minTemp = std::numeric_limits<double>::max();
     double maxTemp = std::numeric_limits<double>::min();
 
-    for (const QVariant &dayVariant : qAsConst(m_weatherData)) {
+    for (const QVariant &dayVariant : std::as_const(m_weatherData)) {
         const auto day = dayVariant.value<KWeatherCore::DailyWeatherForecast>();
 
         const double dayMinTemp = Kweather::convertTemp(day.minTemp(), KWeatherSettings::self()->temperatureUnits());
@@ -88,3 +88,5 @@ double TemperatureChartData::minTempLimit() const
 {
     return m_minTempLimit;
 }
+
+#include "moc_temperaturechartdata.cpp"
